import type { AppRouteRecordRaw, AppRouteModule } from '@/router/types';

import { PAGE_NOT_FOUND_ROUTE, REDIRECT_ROUTE } from '@/router/routes/basic';
import { LAYOUT } from '@/router/constant';
import { mainOutRoutes } from './mainOut';
import { t } from '@/hooks/web/useI18n';

// import.meta.glob() 直接引入所有的模块 Vite 独有的功能
const modules = import.meta.glob('./modules/**/*.ts', { eager: true });
const routeModuleList: AppRouteModule[] = [];

// 加入到路由集合中
Object.keys(modules).forEach((key) => {
  const mod = (modules as Recordable)[key].default || {};
  const modList = Array.isArray(mod) ? [...mod] : [mod];
  routeModuleList.push(...modList);
});

export const asyncRoutes = [PAGE_NOT_FOUND_ROUTE, ...routeModuleList];

// 根路由
export const RootRoute: AppRouteRecordRaw = {
  path: '/',
  name: 'Root',
  redirect: '/homePage/index',
  meta: {
    title: 'Root',
  },
};

export const LoginRoute: AppRouteRecordRaw = {
  path: '/login',
  name: 'Login',
  component: () => import('@/views/sys/login/Login.vue'),
  meta: {
    title: t('routes.basic.login'),
  },
};
//10/24 10点19分 字典类型详情页路由
export const DictRoute: AppRouteRecordRaw = {
  path: '/dict',
  name: 'Dict',
  component: LAYOUT,
  meta: {
    title: '字典管理',
    icon: '',
    currentActiveMenu: '/system/dict',
  },
  children: [
    {
      path: 'type/data',
      name: 'Data',
      component: () => import('@/views/system/dict/data/index.vue'),
      meta: {
        hideMenu: true,
        title: '字典数据',
        icon: '',
      },
    },
  ],
};
//11/20 13点23分 流程中心相关路由
export const processCenterRoute: AppRouteRecordRaw = {
  path: '/processCenter',
  name: 'processCenter',
  component: LAYOUT,
  meta: {
    title: '流程中心',
    icon: '',
    currentActiveMenu: '/processCenter/index',
  },
  children: [
    {
      path: '/processCenter/detailsTab2',
      name: 'detailsTab2',
      component: () => import('@/views/processCenter/detailsTab2/index.vue'),
      meta: {
        title: '待办事项详情页面',
        icon: '',
      },
    },
    {
      path: '/processCenter/detailsTab3',
      name: 'detailsTab3',
      component: () => import('@/views/processCenter/detailsTab3/index.vue'),
      meta: {
        title: '已办事项详情页面',
        icon: '',
      },
    },
  ],
};
export const mainBodyRoute: AppRouteRecordRaw = {
  path: '/mainBody',
  name: 'mainBody',
  component: LAYOUT,
  meta: {
    title: '主体管理',
    icon: '',
    currentActiveMenu: '/mainBody/index',
  },
  children: [
    {
      path: '/mainBody/details',
      name: 'details',
      component: () => import('@/views/mainBody/details/index.vue'),
      meta: {
        title: '主体管理详情',
        icon: '',
      },
    },
  ],
};

/**数据源*/
export const DataSourceRoute: AppRouteRecordRaw = {
  path: '/dataSourceManage',
  name: 'dataSourceManage',
  component: LAYOUT,
  meta: {
    title: '数据源',
    icon: '',
    hidden: true,
    currentActiveMenu: '/mainBody/index',
  },
  children: [
    {
      path: 'connect/CollectRecordModal',
      name: 'collectRecordModal',
      component: () => import('@/views/dataSourceManage/connect/CollectRecordModal.vue'),
      meta: {
        title: '日志详情',
        icon: '',
      },
    },
  ],
};

export const UserRoute: AppRouteRecordRaw = {
  path: '/user',
  name: 'User',
  component: LAYOUT,
  meta: {
    title: '用户管理',
    icon: '',
    hidden: true,
    currentActiveMenu: '/system/user',
  },
  children: [
    {
      path: 'AccountDetail',
      name: 'AccountDetail',
      component: () => import('@/views/system/user/AccountDetail.vue'),
      meta: {
        title: '用户详情',
        icon: '',
      },
    },
  ],
};

/**通用文件*/
export const CommonFileRoute: AppRouteRecordRaw = {
  path: '/commonFile',
  name: 'commonFile',
  component: LAYOUT,
  meta: {
    title: '通用文件操作',
    icon: '',
    hidden: true,
    currentActiveMenu: '/commonFile',
  },
  children: [
    {
      path: 'fileDetail',
      name: 'fileDetail',
      component: () => import('@/views/commonFile/fileDetail.vue'),
      meta: {
        title: '文件详情',
        icon: '',
      },
    },
  ],
};

export const DataWarehousePlanningRoute: AppRouteRecordRaw = {
  path: '/dataWarehousePlanning',
  name: 'logicModel',
  component: LAYOUT,
  meta: {
    title: '编辑模型',
    icon: '',
    hidden: true,
    currentActiveMenu: '/dataWarehousePlanning',
  },
  children: [
    {
      path: 'logicalModel/detail',
      name: 'logicalModel',
      component: () => import('@/views/dataWarehousePlanning/logicalModel/modelDetail/index.vue'),
      meta: {
        title: '逻辑模型详情',
        icon: '',
      },
    },
    {
      path: 'logicalModel/entity-detail',
      name: 'logicalEntityModel',
      component: () =>
        import('@/views/dataWarehousePlanning/logicalModel/modelDetail/entityDetail/index.vue'),
      meta: {
        title: '实体详情',
        icon: '',
      },
    },
    {
      path: 'logicalModel/version-manage',
      name: 'logicalVersionModel',
      component: () => import('@/views/dataWarehousePlanning/logicalModel/versionManage/index.vue'),
      meta: {
        title: '转换记录',
        icon: '',
      },
    },
    {
      path: 'logicalModel/version-comparison',
      name: 'logicalVersionComparisonModel',
      component: () =>
        import(
          '@/views/dataWarehousePlanning/logicalModel/modelDetail/versionComparison/index.vue'
        ),
      meta: {
        title: '版本对比',
        icon: '',
      },
    },
    {
      path: 'logicalModel/ERchart',
      name: 'logicalChartModel',
      component: () =>
        import('@/views/dataWarehousePlanning/logicalModel/modelDetail/ERchart/index.vue'),
      meta: {
        title: '实体关系图',
        icon: '',
      },
    },
    {
      path: 'logicalModel/upload',
      name: 'upload',
      component: () => import('@/views/dataWarehousePlanning/logicalModel/upload/index.vue'),
      meta: {
        title: '申请发布',
        icon: '',
      },
    },
  ],
};

/**物理模型*/
export const DataWarehousephysicalModelRoute: AppRouteRecordRaw = {
  path: '/dataWarehousePlanning',
  name: 'physicalModel',
  component: LAYOUT,
  meta: {
    title: '编辑模型',
    icon: '',
    hidden: true,
    currentActiveMenu: '/dataWarehousePlanning',
  },
  children: [
    {
      path: 'physicalModel/detail',
      name: 'physicalModelDetail',
      component: () => import('@/views/dataWarehousePlanning/physicalModel/modelDetail/index.vue'),
      meta: {
        title: '物理模型详情',
        icon: '',
      },
    },
    {
      path: 'physicalModel/createHistory',
      name: 'physicalModelCreate',
      component: () => import('@/views/dataWarehousePlanning/physicalModel/CreateHistory.vue'),
      meta: {
        title: '建表记录',
        icon: '',
      },
    },
    {
      path: 'physicalModel/relate',
      name: 'relateImage',
      component: () =>
        import(
          '@/views/dataWarehousePlanning/physicalModel/modelDetail/modelRelationship/relateImage.vue'
        ),
      meta: {
        title: '模型关系',
        icon: '',
      },
    },
    {
      path: 'physicalModel/assetRelate',
      name: 'assetER',
      component: () =>
        import('@/views/dataWarehousePlanning/physicalModel/modelDetail/assetRelation/assetER.vue'),
      meta: {
        title: '资产关系图谱',
        icon: '',
      },
    },
    {
      path: 'physicalModel/upload',
      name: 'pupload',
      component: () => import('@/views/dataWarehousePlanning/physicalModel/upload/index.vue'),
      meta: {
        title: '批量发布',
        icon: '',
      },
    },
    {
      path: 'physicalModel/versionManage',
      name: 'versionManage',
      component: () =>
        import('@/views/dataWarehousePlanning/physicalModel/modelDetail/versionIndex.vue'),
      meta: {
        title: '版本对比',
        icon: '',
      },
    },
    {
      path: 'landCheck/detail',
      name: 'landDetail',
      component: () =>
        import('@/views/dataWarehousePlanning/physicalModel/landCheck/checkDetail/index.vue'),
      meta: {
        title: '版本对比',
        icon: '',
      },
    },
    {
      path: 'landCheck/checkReport',
      name: 'checkReport',
      component: () =>
        import('@/views/dataWarehousePlanning/physicalModel/landCheck/checkDetail/checkReport.vue'),
      meta: {
        title: '检核报告',
        icon: '',
      },
    },
  ],
};

/**元模型*/
export const ModelRoute: AppRouteRecordRaw = {
  path: '/metaModel',
  name: 'metaModel',
  component: LAYOUT,
  meta: {
    title: '编辑模型',
    icon: '',
    hidden: true,
    currentActiveMenu: '/metaModel',
  },
  children: [
    {
      path: 'physicsModel/index',
      name: 'physicsModelIndex',
      component: () => import('@/views/metaModel/physicsModel/index.vue'),
      meta: {
        title: '物理模型元模型',
        icon: '',
      },
    },
    {
      path: 'physicsModel/EditRowTable',
      name: 'physicsModel',
      component: () => import('@/views/metaModel/physicsModel/EditRowTable.vue'),
      meta: {
        title: '编辑物理模型',
        icon: '',
      },
    },
    {
      path: 'knowledgeModel/EditRowTable',
      name: 'knowledgeModel',
      component: () => import('@/views/metaModel/knowledgeModel/EditRowTable.vue'),
      meta: {
        title: '编辑知识库模型',
        icon: '',
      },
    },
    {
      path: 'standardModel/EditRowTable',
      name: 'standardModel',
      component: () => import('@/views/metaModel/standardModel/EditRowTable.vue'),
      meta: {
        title: '编辑数据标准模型',
        icon: '',
      },
    },
    {
      path: 'logicModels/EditRowTable',
      name: 'logicModels',
      component: () => import('@/views/metaModel/logicModel/EditRowTable.vue'),
      meta: {
        title: '落地检核详情',
        icon: '',
      },
    },
  ],
};

/**数据标准*/
export const DataStandardRoute: AppRouteRecordRaw = {
  path: '/dataStandards',
  name: 'dataStandards',
  component: LAYOUT,
  meta: {
    title: '数据标准',
    icon: '',
    hidden: true,
    currentActiveMenu: '/dataStandards',
  },
  children: [
    {
      path: 'basicStandards/detailStandard',
      name: 'detailStandard',
      component: () => import('@/views/dataStandards/basicStandards/detailStandard.vue'),
      meta: {
        title: '基础标准详情',
        icon: '',
      },
    },
    {
      path: 'basicStandards/editDetailStandard',
      name: 'editDetailStandard',
      component: () => import('@/views/dataStandards/basicStandards/editDetailStandard.vue'),
      meta: {
        title: '基础标准编辑',
        icon: '',
      },
    },
    {
      path: 'basicStandards/basicStandardsContrast',
      name: 'basicStandardsContrast',
      component: () => import('@/views/dataStandards/basicStandards/basicStandardsContrast.vue'),
      meta: {
        title: '基础标准对比',
        icon: '',
      },
    },
    {
      path: 'basicStandards/relatedRelationships',
      name: 'relatedRelationships',
      component: () => import('@/views/dataStandards/basicStandards/relatedRelationships.vue'),
      meta: {
        title: '基础标准关联关系',
        icon: '',
      },
    },
    {
      path: 'basicStandards/applyPublication',
      name: 'applyPublication1',
      component: () => import('@/views/dataStandards/basicStandards/applyPublication.vue'),
      meta: {
        title: '申请发布',
        icon: '',
      },
    },
    {
      path: 'IndicatorStandards/detailStandard',
      name: 'detailStandard1',
      component: () => import('@/views/dataStandards/IndicatorStandards/detailStandard.vue'),
      meta: {
        title: '指标标准详情',
        icon: '',
      },
    },
    {
      path: 'IndicatorStandards/editDetailStandard',
      name: 'editDetailStandard1',
      component: () => import('@/views/dataStandards/IndicatorStandards/editDetailStandard.vue'),
      meta: {
        title: '指标标准编辑',
        icon: '',
      },
    },
    {
      path: 'IndicatorStandards/basicStandardsContrast',
      name: 'basicStandardsContrast1',
      component: () =>
        import('@/views/dataStandards/IndicatorStandards/indicatorStandardsContrast.vue'),
      meta: {
        title: '指标标准对比',
        icon: '',
      },
    },
    {
      path: 'IndicatorStandards/relatedRelationships',
      name: 'relatedRelationships1',
      component: () => import('@/views/dataStandards/IndicatorStandards/relatedRelationships.vue'),
      meta: {
        title: '指标标准关联关系',
        icon: '',
      },
    },
    {
      path: 'IndicatorStandards/applyPublication',
      name: 'applyPublication2',
      component: () => import('@/views/dataStandards/IndicatorStandards/applyPublication.vue'),
      meta: {
        title: '申请发布',
        icon: '',
      },
    },
    {
      path: 'labelDropInspection/labelDetail',
      name: 'labelDropDetail',
      component: () => import('@/views/dataStandards/labelDropInspection/labelDetail/index.vue'),
      meta: {
        title: '落标检查详情',
        icon: '',
      },
    },
    {
      path: 'labelDropInspection/labelReport',
      name: 'labelReport',
      component: () => import('@/views/dataStandards/labelDropInspection/labelReport/index.vue'),
      meta: {
        title: '查看落标报告',
        icon: '',
      },
    },
    {
      path: 'publicCode/detailPublicCode',
      name: 'detailPublicCode',
      component: () => import('@/views/dataStandards/publicCode/detailPublicCode.vue'),
      meta: {
        title: '公共代码详情',
        icon: '',
      },
    },
    {
      path: 'publicCode/editDetail',
      name: 'editDetail',
      component: () => import('@/views/dataStandards/publicCode/editDetail.vue'),
      meta: {
        title: '公共代码编辑',
        icon: '',
      },
    },
    {
      path: 'publicCode/publicCodeContrast',
      name: 'publicCodeContrast',
      component: () => import('@/views/dataStandards/publicCode/publicCodeContrast.vue'),
      meta: {
        title: '公共代码对比',
        icon: '',
      },
    },
    {
      path: 'publicCode/relatedRelationships',
      name: 'relatedRelationships2',
      component: () => import('@/views/dataStandards/publicCode/relatedRelationships.vue'),
      meta: {
        title: '公共代码关联关系',
        icon: '',
      },
    },
    {
      path: 'publicCode/applyPublication',
      name: 'applyPublication3',
      component: () => import('@/views/dataStandards/publicCode/applyPublication.vue'),
      meta: {
        title: '申请发布',
        icon: '',
      },
    },
  ],
};

/**工作区*/
export const WorkSpaceRoute: AppRouteRecordRaw = {
  path: '/workspace',
  name: 'Workspace',
  component: LAYOUT,
  meta: {
    title: '工作区管理',
    icon: '',
    hidden: true,
    currentActiveMenu: '/system/workspace',
  },
  children: [
    {
      path: 'detail',
      name: 'Detail',
      component: () => import('@/views/system/workspace/detail.vue'),
      meta: {
        title: '工作区详情',
        icon: '',
      },
    },
  ],
};

/**质量规则*/
export const QualityRuleRoute: AppRouteRecordRaw = {
  path: '/dataQuality',
  name: 'QualityRule',
  component: LAYOUT,
  meta: {
    title: '质量规则管理',
    icon: '',
    hidden: true,
    currentActiveMenu: '/dataQuality/dataSheet/rule',
  },
  children: [
    {
      path: 'dataSheet/rule',
      name: 'rule',
      component: () => import('@/views/dataQuality/dataSheet/rule/index.vue'),
      meta: {
        title: '质量规则批量创建',
        icon: '',
      },
    },
    {
      path: 'ruleMoreAdd',
      name: 'RuleMoreAdd',
      component: () => import('@/views/dataQuality/dataSheet/rule/ruleMoreAdd.vue'),
      meta: {
        title: '质量规则批量创建',
        icon: '',
      },
    },
    {
      path: 'edit',
      name: 'Edit',
      component: () => import('@/views/dataQuality/dataSheet/rule/parameter/edit.vue'),
      meta: {
        title: '质量参数编辑',
        icon: '',
      },
    },
  ],
};

/**血缘解析*/
export const kinshipParseRoute: AppRouteRecordRaw = {
  path: '/kinship/kinshipParse',
  name: 'kinshipParse',
  component: LAYOUT,
  meta: {
    title: '血缘解析',
    icon: '',
    hidden: true,
    currentActiveMenu: '/kinship/kinshipParse',
  },
  children: [
    {
      path: 'parse',
      name: 'Parse',
      component: () => import('@/views/kinship/kinshipParse/parse.vue'),
      meta: {
        title: '脚本解析',
        icon: '',
      },
    },
  ],
};

/**Sql开发*/
export const sqlExecuteRoute: AppRouteRecordRaw = {
  path: '/scriptDevelopment/sqlDevelopment/sqlExecute',
  name: 'sqlExecute',
  component: LAYOUT,
  meta: {
    title: 'Sql开发',
    icon: '',
    hidden: true,
    currentActiveMenu: '/scriptDevelopment/sqlDevelopment/sqlExecute',
  },
  children: [
    {
      path: 'sqlExecute',
      name: 'SqlExecute',
      component: () => import('@/views/scriptDevelopment/sqlDevelopment/sqlExecute/sqlExecute.vue'),
      meta: {
        title: 'Sql执行',
        icon: '',
      },
    },
  ],
};
/**shell开发*/
export const shellExecuteRoute: AppRouteRecordRaw = {
  path: '/scriptDevelopment/shellDevelopment/shellExecute',
  name: 'shellExecute',
  component: LAYOUT,
  meta: {
    title: 'Shell开发',
    icon: '',
    hidden: true,
    currentActiveMenu: '/scriptDevelopment/shellDevelopment/shellExecute',
  },
  children: [
    {
      path: 'shellExecute',
      name: 'ShellExecute',
      component: () =>
        import('@/views/scriptDevelopment/shellDevelopment/shellExecute/shellExecute.vue'),
      meta: {
        title: 'Shell执行',
        icon: '',
      },
    },
  ],
};

/**数据服务*/
export const serviceDevelopmentRoute: AppRouteRecordRaw = {
  path: '/dataService',
  name: 'dataService',
  component: LAYOUT,
  meta: {
    title: '数据服务',
    icon: '',
    hidden: true,
    currentActiveMenu: '/dataService',
  },
  children: [
    {
      path: 'serviceDevelopment/fileDetails',
      name: 'fileDetails1',
      component: () => import('@/views/dataService/serviceDevelopment/index.vue'),
      meta: {
        title: '服务开发模块描述',
        icon: '',
      },
    },
    {
      path: 'serviceDevelopment/apiContrast',
      name: 'apiContrast1',
      component: () => import('@/views/dataService/serviceDevelopment/apiContrast.vue'),
      meta: {
        title: '服务开发api对比',
        icon: '',
      },
    },
    {
      path: 'serviceDevelopment/ApiDoc',
      name: 'ApiDoc',
      component: () => import('@/views/dataService/serviceDevelopment/ApiDoc.vue'),
      meta: {
        title: 'ApiDoc',
        icon: '',
      },
    },
    {
      path: 'serviceDevelopment/guideModeApi',
      name: 'guideModeApi',
      component: () => import('@/views/dataService/serviceDevelopment/guideModeApi.vue'),
      meta: {
        title: '向导模式',
        icon: '',
      },
    },
    {
      path: 'serviceDevelopment/sqlModeApi',
      name: 'sqlModeApi',
      component: () => import('@/views/dataService/serviceDevelopment/sqlModeApi.vue'),
      meta: {
        title: 'SQL模式',
        icon: '',
      },
    },
    {
      path: 'serviceDevelopment/trusteeshipModeApi',
      name: 'trusteeshipModeApi',
      component: () => import('@/views/dataService/serviceDevelopment/trusteeshipModeApi.vue'),
      meta: {
        title: '托管模式',
        icon: '',
      },
    },
    {
      path: 'serviceDevelopment/trusteeshipApiTest',
      name: 'trusteeshipApiTest',
      component: () => import('@/views/dataService/serviceDevelopment/trusteeshipApiTest.vue'),
      meta: {
        title: 'API测试',
        icon: '',
      },
    },
    {
      path: 'serviceDevelopment/trusteeshipApiTestResult',
      name: 'trusteeshipApiTestResult',
      component: () =>
        import('@/views/dataService/serviceDevelopment/trusteeshipApiTestResult.vue'),
      meta: {
        title: '测试结果',
        icon: '',
      },
    },
    {
      path: 'serviceMonitor/useLog',
      name: 'useLog',
      component: () => import('@/views/dataService/serviceMonitor/logMangae.vue'),
      meta: {
        title: '日志管理',
        icon: '',
      },
    },
    {
      path: 'serviceDevelopment/apiDetail',
      name: 'apiDetail',
      component: () => import('@/views/dataService/serviceDevelopment/apiDetail.vue'),
      meta: {
        title: 'API详情',
        icon: '',
      },
    },

    //服务管理-api上线管理
    {
      path: 'serviceManage/onlineManage/handleConsanguinity',
      name: 'handleConsanguinity',
      component: () =>
        import('@/views/dataService/serviceManage/onlineManage/handleConsanguinity.vue'),
      meta: {
        title: '血缘详情',
        icon: '',
      },
    },
    {
      path: 'serviceManage/onlineManage/productionData',
      name: 'productionData',
      component: () =>
        import('@/views/dataService/serviceManage/onlineManage/productionData.vue'),
      meta: {
        title: '上线设置',
        icon: '',
      },
    },
    {
      path: 'serviceManage/onlineManage/productionTest',
      name: 'productionTest',
      component: () =>
        import('@/views/dataService/serviceManage/onlineManage/productionTest.vue'),
      meta: {
        title: '上线测试',
        icon: '',
      },
    },
  ],
};

/**实时同步-任务运维*/
export const SyncMaintenanceRoute: AppRouteRecordRaw = {
  path: '/realTimeSync',
  name: 'realTimeSync',
  component: LAYOUT,
  meta: {
    title: '实时同步',
    icon: '',
    hidden: true,
    currentActiveMenu: '/realTimeSync',
  },
  children: [
    {
      path: 'taskOperationsMaintenance/workDetail',
      name: 'workDetail',
      component: () => import('@/views/realTimeSync/taskOperationsMaintenance/workDetail.vue'),
    },
  ],
};
// Basic routing without permission
// 没有权限要求的基本路由
export const basicRoutes = [
  LoginRoute,
  DictRoute,
  mainBodyRoute,
  UserRoute,
  WorkSpaceRoute,
  CommonFileRoute,
  ModelRoute,
  DataSourceRoute,
  DataStandardRoute,
  kinshipParseRoute,
  serviceDevelopmentRoute,
  RootRoute,
  sqlExecuteRoute,
  shellExecuteRoute,
  SyncMaintenanceRoute,
  ...mainOutRoutes,
  REDIRECT_ROUTE,
  DataWarehousePlanningRoute,
  DataWarehousephysicalModelRoute,
  PAGE_NOT_FOUND_ROUTE,
  QualityRuleRoute,
  processCenterRoute,
];
